import { Injectable } from '@nestjs/common';
import { BaseService } from '../base/base.service';
import {
  UserProfile,
  db,
  ObjectType,
  Prisma,
  Resource,
} from '@nicestack/common';
import { createHash } from 'crypto';

@Injectable()
export class ResourceService extends BaseService<Prisma.ResourceDelegate> {
  constructor() {
    super(db, ObjectType.RESOURCE);
  }
  async create(
    args: Prisma.ResourceCreateArgs,
    params?: { staff?: UserProfile },
  ): Promise<Resource> {
    if (params?.staff) {
      args.data.ownerId = params?.staff?.id
    }
    return this.create(args);
  }
  async checkFileExists(hash: string): Promise<Resource | null> {
    return this.findFirst({
      where: {
        hash,
        deletedAt: null,
      },
    });
  }
  async calculateFileHash(buffer: Buffer): Promise<string> {
    return createHash('sha256').update(buffer).digest('hex');
  }

}